@@ -2,7 +2,7 @@
 
 /* nntp-method.c - VFS module for NNTP
 
-   Copyright (C) 2001, 2002 Andy Hertzfeld
+   Copyright (C) 2001 Andy Hertzfeld
 
    The Gnome Library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public License as
@@ -32,7 +32,6 @@
 #include <config.h>
 #endif
 
-#include <ctype.h> /* for isspace */
 #include <stdlib.h> /* for atoi */
 #include <stdio.h> /* for sscanf */
 #include <string.h>
@@ -41,22 +40,21 @@
 #include <netinet/in.h>
 #include <arpa/inet.h>
 
-#include <gtk/gtk.h>
+#include <glib.h>
+
 #ifdef HAVE_GCONF
 #include <gconf/gconf-client.h>
 #endif
 
-#include "gnome-vfs-context.h"
-#include "gnome-vfs-iobuf.h"
-#include "gnome-vfs-inet-connection.h"
-#include "gnome-vfs-method.h"
-#include "gnome-vfs-module.h"
-#include "gnome-vfs-module-shared.h"
-#include <libgnomevfs/gnome-vfs-module-callback-module-api.h>
-#include <libgnomevfs/gnome-vfs-standard-callbacks.h>
-#include "gnome-vfs-mime.h"
-#include "gnome-vfs-parse-ls.h"
-#include "gnome-vfs-utils.h"
+#include <libgnomevfs/gnome-vfs-context.h>
+#include <libgnomevfs/gnome-vfs-iobuf.h>
+#include <libgnomevfs/gnome-vfs-inet-connection.h>
+#include <libgnomevfs/gnome-vfs-method.h>
+#include <libgnomevfs/gnome-vfs-module.h>
+#include <libgnomevfs/gnome-vfs-module-shared.h>
+#include <libgnomevfs/gnome-vfs-mime.h>
+#include <libgnomevfs/gnome-vfs-parse-ls.h>
+#include <libgnomevfs/gnome-vfs-utils.h>
 
 #include "nntp-method.h"
 
@@ -86,7 +84,6 @@ static GnomeVFSResult do_open_directory  (GnomeVFSMethod                *method,
 					  GnomeVFSMethodHandle         **method_handle,
 					  GnomeVFSURI                   *uri,
 					  GnomeVFSFileInfoOptions        options,
-					  const GnomeVFSDirectoryFilter *filter,
 					  GnomeVFSContext               *context);
 static GnomeVFSResult do_close_directory (GnomeVFSMethod               *method,
 					  GnomeVFSMethodHandle          *method_handle,
@@ -97,13 +94,13 @@ static GnomeVFSResult do_read_directory  (GnomeVFSMethod               *method,
 		                          GnomeVFSContext               *context);
 
 guint                 nntp_connection_uri_hash  (gconstpointer c);
-gint                  nntp_connection_uri_equal (gconstpointer c, gconstpointer d);
+int                   nntp_connection_uri_equal (gconstpointer c, gconstpointer d);
 static GnomeVFSResult nntp_connection_acquire   (GnomeVFSURI *uri, 
 		                                NNTPConnection **connection, 
 		                                GnomeVFSContext *context);
 static void           nntp_connection_release   (NNTPConnection *conn);
 
-static GList* assemble_files_from_overview (NNTPConnection *conn, gchar *command); 
+static GList* assemble_files_from_overview (NNTPConnection *conn, char *command); 
 
 static const char *anon_user = "anonymous";
 static const char *anon_pass = "nobody@gnome.org";
@@ -113,17 +110,17 @@ static const int   nntp_port = 119;
 /* A GHashTable of GLists of NNTPConnections */
 static GHashTable *spare_connections = NULL;
 G_LOCK_DEFINE_STATIC (spare_connections);
-static gint total_connections = 0;
-static gint allocated_connections = 0;
+static int total_connections = 0;
+static int allocated_connections = 0;
 
 /* single element cache of file objects for a given newsgroup */
-static gchar* current_newsgroup_name = NULL;
+static char* current_newsgroup_name = NULL;
 static GList* current_newsgroup_files = NULL;
 
 static GnomeVFSResult 
 nntp_response_to_vfs_result (NNTPConnection *conn) 
 {
-	gint response = conn->response_code;
+	int response = conn->response_code;
 
 	switch (response) {
 	case 421: 
@@ -160,10 +157,10 @@ nntp_response_to_vfs_result (NNTPConnection *conn)
 
 }
 
-static GnomeVFSResult read_response_line(NNTPConnection *conn, gchar **line) {
+static GnomeVFSResult read_response_line(NNTPConnection *conn, char **line) {
 	GnomeVFSFileSize bytes = MAX_RESPONSE_SIZE, bytes_read;
-	gchar *ptr, *buf = g_malloc (MAX_RESPONSE_SIZE+1);
-	gint line_length;
+	char *ptr, *buf = g_malloc (MAX_RESPONSE_SIZE+1);
+	int line_length;
 	GnomeVFSResult result = GNOME_VFS_OK;
 
 	while (!strstr (conn->response_buffer->str, "\r\n")) {
@@ -202,7 +199,7 @@ get_response (NNTPConnection *conn)
 	GnomeVFSResult result;
 
 	while (TRUE) {
-		gchar *line = NULL;
+		char *line = NULL;
 		result = read_response_line (conn, &line);
 
 		if (result != GNOME_VFS_OK) {
@@ -212,12 +209,14 @@ get_response (NNTPConnection *conn)
 		}
 		
 		/* response needs to be at least: "### x"  - I think*/
-		if (isdigit ((unsigned char) line[0]) &&
-		    isdigit ((unsigned char) line[1]) &&
-		    isdigit ((unsigned char) line[2]) &&
-		    isspace ((unsigned char) line[3])) {
+		if (g_ascii_isdigit (line[0]) &&
+		    g_ascii_isdigit (line[1]) &&
+		    g_ascii_isdigit (line[2]) &&
+		    g_ascii_isspace (line[3])) {
 
-			conn->response_code = (line[0] - '0') * 100 + (line[1] - '0') * 10 + (line[2] - '0');
+			conn->response_code = g_ascii_digit_value (line[0]) * 100
+			                      + g_ascii_digit_value (line[1]) * 10
+					      + g_ascii_digit_value (line[2]);
 
 			if (conn->response_message) g_free (conn->response_message);
 			conn->response_message = g_strdup (line+4);
@@ -237,9 +236,9 @@ get_response (NNTPConnection *conn)
 }
 
 static GnomeVFSResult do_control_write (NNTPConnection *conn, 
-					gchar *command) 
+					char *command) 
 {
-        gchar *actual_command = g_strdup_printf ("%s\r\n", command);
+        char *actual_command = g_strdup_printf ("%s\r\n", command);
 	GnomeVFSFileSize bytes = strlen (actual_command), bytes_written;
 	GnomeVFSResult result = gnome_vfs_iobuf_write (conn->iobuf,
 						       actual_command, bytes, &bytes_written);
@@ -257,7 +256,7 @@ nntp_connection_reset_buffer (NNTPConnection *conn)
 
 static GnomeVFSResult 
 do_basic_command (NNTPConnection *conn, 
-		  gchar *command) 
+		  char *command) 
 {
 	GnomeVFSResult result;
 
@@ -270,6 +269,7 @@ do_basic_command (NNTPConnection *conn,
 	}
 
 	result = get_response (conn);
+
 	return result;
 }
 
@@ -281,10 +281,10 @@ nntp_connection_create (NNTPConnection **connptr, GnomeVFSURI *uri, GnomeVFSCont
 {
 	NNTPConnection *conn = g_new (NNTPConnection, 1);
 	GnomeVFSResult result;
-	gchar *tmpstring;
-	gint port = nntp_port;
-	const gchar *user = anon_user;
-	const gchar *pass = anon_pass;
+	char *tmpstring;
+	int port = nntp_port;
+	const char *user = anon_user;
+	const char *pass = anon_pass;
 	
 	conn->uri = gnome_vfs_uri_dup (uri);
 	
@@ -411,15 +411,15 @@ nntp_connection_destroy (NNTPConnection *conn)
 /* hash routines for managing the pool of connections */
 /* g_str_hash and g_str_equal seem to fail with null arguments */
 
-static gint 
-my_str_hash (const gchar *c) 
+static int 
+my_str_hash (const char *c) 
 {
 	if (c) 
 	        return g_str_hash (c);
 	else return 0;
 }
 
-static gint 
+static int 
 my_str_equal (gconstpointer c, 
 	      gconstpointer d) 
 {
@@ -445,7 +445,7 @@ nntp_connection_uri_hash (gconstpointer c)
 /* test the equality of the bits of a GnomeVFSURI that distingush NNTP 
  * connections
  */
-gint 
+int 
 nntp_connection_uri_equal (gconstpointer c, 
 			  gconstpointer d) 
 {
@@ -547,16 +547,17 @@ nntp_connection_release (NNTPConnection *conn)
  * helper routines
  */
 static gboolean
-is_number_or_space(char test_char)
+is_number_or_space (char test_char)
 {
-	return isspace(test_char) || isdigit(test_char) || test_char == '_' || test_char == '-' || test_char == '/';
+	return g_ascii_isspace (test_char) || g_ascii_isdigit (test_char)
+	       || test_char == '_' || test_char == '-' || test_char == '/';
 }
 
 static gboolean
-all_numbers_or_spaces( gchar *left_ptr, gchar *right_ptr)
+all_numbers_or_spaces (char *left_ptr, char *right_ptr)
 {
-	gchar *current_char_ptr;
-	gchar current_char;
+	char *current_char_ptr;
+	char current_char;
 	
 	current_char_ptr = left_ptr;
 	while (current_char_ptr < right_ptr) {
@@ -623,14 +624,14 @@ remove_number_at_end (char *input_str)
 	}
 }
 
-static gchar*
+static char*
 trim_nonalpha_chars (char *input_str)
 {
 	char *left_ptr, *right_ptr;
 
 	/* first handle the end of the string */	
 	right_ptr = input_str + strlen(input_str) - 1;
-	while (!isalnum (*right_ptr) && right_ptr > input_str) {
+	while (!g_ascii_isalnum (*right_ptr) && right_ptr > input_str) {
 		right_ptr -= 1;
 	}
 	
@@ -639,7 +640,7 @@ trim_nonalpha_chars (char *input_str)
 
 	/* now handle the beginning */
 	left_ptr = input_str;
-	while (*left_ptr && !isalnum(*left_ptr)) {
+	while (*left_ptr && !g_ascii_isalnum(*left_ptr)) {
 		left_ptr++;
 	}
 	return left_ptr;
@@ -665,11 +666,11 @@ remove_of_expressions (char *input_str)
 		right_ptr = left_ptr + 2;
 		left_ptr = left_ptr - 1;
 		while (is_number_or_space(*left_ptr) && left_ptr >= input_str) {
-			found_number = found_number || isdigit(*left_ptr);
+			found_number = found_number || g_ascii_isdigit(*left_ptr);
 			left_ptr -= 1;
 		}
 		while (is_number_or_space(*right_ptr)) {
-			found_number = found_number || isdigit(*right_ptr);
+			found_number = found_number || g_ascii_isdigit(*right_ptr);
 			right_ptr += 1;
 		}
 		
@@ -688,7 +689,7 @@ remove_of_expressions (char *input_str)
 /* here is the main folder name filtering routine, which returns a new string containing the filtered
  * version of the passed-in folder name
  */
-static gchar *
+static char *
 filter_folder_name(char *folder_name)
 {
 	char *temp_str, *save_str, *result_str;
@@ -730,7 +731,7 @@ filter_folder_name(char *folder_name)
 	/* truncate if necessary */
 	if (strlen(temp_str) > 30) {
 		left_ptr = temp_str + 29;
-		while (isalpha(*left_ptr)) {
+		while (g_ascii_isalpha(*left_ptr)) {
 			left_ptr += 1;
 		}
 		
@@ -746,9 +747,9 @@ filter_folder_name(char *folder_name)
 /* parse dates by allowing gnome-vfs to do most of the work */
 
 static void
-remove_commas(gchar *source_str)
+remove_commas(char *source_str)
 {
-	gchar *ptr;
+	char *ptr;
 	
 	ptr = source_str;
 	while (*ptr != '\0') {
@@ -761,12 +762,12 @@ remove_commas(gchar *source_str)
 }
 
 static gboolean
-is_number(gchar *input_str) {
-	gchar *cur_char;
+is_number(char *input_str) {
+	char *cur_char;
 	
 	cur_char = input_str;
 	while (*cur_char) {
-		if (!isdigit(*cur_char)) {
+		if (!g_ascii_isdigit(*cur_char)) {
 			return FALSE;
 		}
 		cur_char += 1;
@@ -775,14 +776,14 @@ is_number(gchar *input_str) {
 }
 
 static void
-parse_date_string (const gchar* date_string, time_t *t)
+parse_date_string (const char* date_string, time_t *t)
 {
 	struct stat s;
-	gchar *filename, *linkname;
-	gchar *temp_str, *mapped_date;
+	char *filename, *linkname;
+	char *temp_str, *mapped_date;
 	gboolean result;
-	gchar **date_parts;
-	gint offset;
+	char **date_parts;
+	int offset;
 	
 	filename = NULL;
 	linkname = NULL;
@@ -827,7 +828,7 @@ parse_header(const char* header_str, char** filename, char** folder_name, char**
 	char* left_paren, *right_paren, *slash_pos;
  	int slash_bump;
 	
-	gchar **header_parts;
+	char **header_parts;
   	gboolean has_count;
 	
 	*part_number = -1;
@@ -941,10 +942,10 @@ nntp_fragment_destroy(nntp_fragment* fragment)
 /* utility routine to map slashes to dashes in the passed in string so we never return
  * a filename with slashes
  */
-static gchar *
-map_slashes(gchar *str)
+static char *
+map_slashes(char *str)
 {
-	gchar *current_ptr;
+	char *current_ptr;
 	
 	current_ptr = str;
 	while (*current_ptr != '\0') {
@@ -1059,14 +1060,14 @@ nntp_file_add_part (nntp_file *file, int fragment_number, char* fragment_id, int
 
 /* look up a file object in the file list from its name; avoid lookup if same as last time (soon) */
 static nntp_file*
-look_up_file (GList *file_list, gchar *filename, gboolean is_directory)
+look_up_file (GList *file_list, char *filename, gboolean is_directory)
 {
 	nntp_file* file;
 	GList* current_file = file_list;
 	while (current_file != NULL) {
 		file = (nntp_file*) current_file->data;
-		if (g_strcasecmp( file->file_name, filename) == 0 && 
-				file->is_directory == is_directory) {
+		if (g_ascii_strcasecmp( file->file_name, filename) == 0 && 
+		    file->is_directory == is_directory) {
 			return file;
 		}
 		current_file = current_file->next;
@@ -1079,8 +1080,8 @@ static GnomeVFSResult
 start_loading_article (NNTPConnection *conn, nntp_fragment *fragment)
 {
 	GnomeVFSResult result;
-	gchar *command_str;
-	gchar *line = NULL;
+	char *command_str;
+	char *line = NULL;
 	
 	/* issue the command to fetch the article */
 	command_str = g_strdup_printf("BODY %s", fragment->fragment_id);
@@ -1219,8 +1220,8 @@ static GnomeVFSResult
 load_from_article (NNTPConnection *conn, nntp_fragment *fragment, gboolean first_line_flag)
 {
 	GnomeVFSResult result;
-	gchar *line = NULL;
-	gchar *dest_ptr;
+	char *line = NULL;
+	char *dest_ptr;
 	int buffer_offset;
 	int line_len;
 			
@@ -1254,7 +1255,7 @@ load_from_article (NNTPConnection *conn, nntp_fragment *fragment, gboolean first
 				g_message("Error! exceeded buffer! %d", buffer_offset + line_len);
 				line_len = conn->buffer_size - buffer_offset;
 			}
-			dest_ptr = (gchar*) conn->buffer + buffer_offset;
+			dest_ptr = (char*) conn->buffer + buffer_offset;
 			g_memmove(dest_ptr, line, line_len);
 			if (conn->uu_decode_mode) {
 				line_len = uu_decode_text(dest_ptr, line_len);
@@ -1395,30 +1396,6 @@ free_nntp_file_list (GList *file_list)
 	g_list_free (file_list);
 }
 
-/* utility to obtain authorization info from gnome-vfs */
-static void
-get_auth_info (NNTPConnection *conn, char** user, char** password)
-{
-	GnomeVFSResult res;
-	GnomeVFSModuleCallbackAuthenticationIn in_args;
-	GnomeVFSModuleCallbackAuthenticationOut out_args;
-	
-	*user = NULL;
-	*password = NULL;
-	
-	memset (&in_args, 0, sizeof (in_args));			
-	memset (&out_args, 0, sizeof (out_args));
-	
-	in_args.uri = gnome_vfs_uri_to_string(conn->uri, 0);			
-	res = gnome_vfs_module_callback_invoke (GNOME_VFS_MODULE_CALLBACK_AUTHENTICATION,
-						&in_args, sizeof (in_args), 
-							&out_args, sizeof (out_args));	
-	g_free(in_args.uri);
-						
-	*user = out_args.username;
-	*password = out_args.password;
-}
-
 /* key routine to load the newsgroup overview and return a list of nntp_file objects.
  * It maintains a cache to avoid reloading.
  *
@@ -1429,14 +1406,13 @@ static GnomeVFSResult
 get_files_from_newsgroup (NNTPConnection *conn, const char* newsgroup_name, GList** result_file_list)
 {
 	GnomeVFSResult result;
-	gchar *group_command, *tmpstring;
+	char *group_command;
 	int first_message, last_message, total_messages;
-	gchar *command_str;
+	char *command_str;
 	GList *file_list;
-	gchar *user, *pass;
 	
 	/* see if we can load it from the cache */	
-	if (current_newsgroup_name != NULL && g_strcasecmp (newsgroup_name, current_newsgroup_name) == 0) {
+	if (current_newsgroup_name != NULL && g_ascii_strcasecmp (newsgroup_name, current_newsgroup_name) == 0) {
 		*result_file_list = current_newsgroup_files;
 		return GNOME_VFS_OK;
 	}
@@ -1455,33 +1431,8 @@ get_files_from_newsgroup (NNTPConnection *conn, const char* newsgroup_name, GLis
 	g_free (group_command);
 	
 	if (result != GNOME_VFS_OK || conn->response_code != 211) {
-		/* if we're anonymous, prompt for a password and try that */
-		if (conn->anonymous) {
-			get_auth_info(conn, &user, &pass);
-			if (user != NULL) {
-				conn->anonymous = FALSE;				
-				tmpstring = g_strdup_printf ("AUTHINFO user %s", user);
-				result = do_basic_command (conn, tmpstring);
-				g_free (tmpstring);
-
-				if (IS_300 (conn->response_code)) {
-					tmpstring = g_strdup_printf ("AUTHINFO pass %s", pass);
-					result = do_basic_command (conn, tmpstring);
-					g_free (tmpstring);
-				
-					group_command = g_strdup_printf ("GROUP %s", newsgroup_name);
-					result = do_basic_command (conn, group_command);
-					g_free (group_command);	
-				}
-			}
-			g_free (user);
-			g_free (pass);
-		}
-		
-		if (result != GNOME_VFS_OK || conn->response_code != 211) {
-			g_message ("couldnt set group to %s, code %d", newsgroup_name, conn->response_code);
-				return GNOME_VFS_ERROR_NOT_FOUND; /* could differentiate error better */
-		}
+		g_message ("couldnt set group to %s, code %d", newsgroup_name, conn->response_code);
+			return GNOME_VFS_ERROR_NOT_FOUND; /* could differentiate error better */
 	}
 	
 	sscanf (conn->response_message, "%d %d %d", &total_messages, &first_message, &last_message);
@@ -1529,9 +1480,9 @@ strip_slashes (char* source_string)
 static void
 extract_newsgroup_and_filename(GnomeVFSURI *uri, char** newsgroup, char **directory, char **filename)
 {
-	gchar *dirname, *slash_pos;
+	char *dirname, *slash_pos;
 	
-	*filename = gnome_vfs_unescape_string(gnome_vfs_uri_get_basename(uri), "");
+	*filename = gnome_vfs_unescape_string(gnome_vfs_uri_extract_short_name (uri), "");
 	*directory = NULL;
 	 
 	dirname = strip_slashes(gnome_vfs_uri_extract_dirname(uri));
@@ -1666,6 +1617,7 @@ add_file_to_folder (GHashTable *folders, nntp_file *file)
 	} else {
 		folder_contents = g_list_append(NULL, file);
 		g_hash_table_insert (folders, g_strdup(file->folder_name), folder_contents);
+		/* g_message("new folder %s", file->folder_name); */
 	}
 }
 
@@ -1818,10 +1770,10 @@ assemble_folders (GList *file_list)
  * fragments into a list of files
  */
 static GList* 
-assemble_files_from_overview (NNTPConnection *conn, gchar *command) 
+assemble_files_from_overview (NNTPConnection *conn, char *command) 
 {
 	GnomeVFSResult result;
-	gchar *line = NULL;
+	char *line = NULL;
 	int message_size;
 	int part_number, total_parts;
 	char* filename, *folder_name, *message_id;
@@ -1903,7 +1855,7 @@ do_open (GnomeVFSMethod *method,
 	const char* basename;
 
 	/* we can save allocating a connection to search for the .directory file */
-	basename = gnome_vfs_uri_get_basename(uri);
+	basename = gnome_vfs_uri_extract_short_name(uri);
 	if (strcmp(basename, ".directory") == 0) {
 		return GNOME_VFS_ERROR_NOT_FOUND;
 	}
@@ -1969,10 +1921,7 @@ do_get_file_info (GnomeVFSMethod *method,
 	GnomeVFSResult result;
 
 	host_name = gnome_vfs_uri_get_host_name(uri);
-	if (host_name == NULL) {
-		return GNOME_VFS_ERROR_INVALID_HOST_NAME;
-	}
-	
+
 	/* if it's the top level newsgroup, treat it like a directory */	
 	temp_str = gnome_vfs_uri_get_path(uri);
 	first_slash = strchr(temp_str + 1, '/');	
@@ -1990,10 +1939,10 @@ do_get_file_info (GnomeVFSMethod *method,
 		return GNOME_VFS_OK;
 	} else {
 		GnomeVFSMethodHandle *method_handle;
-		gchar *name;
+		char *name;
 		
 		result = do_open_directory (method, &method_handle, parent,
-					    options, NULL, context);
+					    options, context);
 		gnome_vfs_uri_unref (parent);
 
 		if (result != GNOME_VFS_OK) {
@@ -2040,7 +1989,6 @@ do_open_directory (GnomeVFSMethod *method,
 		   GnomeVFSMethodHandle **method_handle,
 		   GnomeVFSURI *uri,
 		   GnomeVFSFileInfoOptions options,
-		   const GnomeVFSDirectoryFilter *filter,
 		   GnomeVFSContext *context)
 {
 	const char *newsgroup_server;
@@ -2054,19 +2002,14 @@ do_open_directory (GnomeVFSMethod *method,
 	
 	newsgroup_server = gnome_vfs_uri_get_host_name (uri);
 	newsgroup_name = gnome_vfs_uri_extract_dirname (uri);
-	directory_name = g_strdup (gnome_vfs_uri_get_basename (uri));
-		
+	directory_name = g_strdup (gnome_vfs_uri_extract_short_name (uri));
+	
 	if (strcmp (newsgroup_name, "/") == 0) {
 		g_free (newsgroup_name);
 		newsgroup_name = directory_name;
 		directory_name = NULL;
 	}
 
-	if (newsgroup_name == NULL) {
-		g_free(directory_name);
-		return GNOME_VFS_ERROR_NOT_FOUND;
-	}
-
 	newsgroup_name = strip_slashes (newsgroup_name);
 	result = nntp_connection_acquire (uri, &conn, context);
 	if (result != GNOME_VFS_OK) {
